-----------------------------------------------------------------------
--			FINANCIAL CALCULATOR
-----------------------------------------------------------------------
--	Author:  Jaime Marcos	<jmarcos2@xtec.net>	    October '06


global constant FALSE	 = 0, TRUE   = 1, NOT_FOUND = -1
global constant KEYBOARD = 0, SCREEN = 1, ERR = 2
global constant e_   = 2.718281828459045     -- 6121_026514_868073/2^51
global constant inf_ = tan(2*arctan(1))
global constant NaN_ = -(inf_/inf_)

global function abs(atom x)
		    if x<0 then x=-x end if return x end function --abs

global function ipp(atom ina, atom cf, atom pf)
			-- formulae:  (1+i)^pf = (1+ina/cf)^cf = 1+TAE
			-- ipp = interest rate per period, i
			-- ina = interest nominal annual = NAR
			-- cf  = compounding frequency (can be inf_)
			-- pf  = payment frequency
			-- TAE = effective annual rate
    if cf < inf_ then
	return power(ina/cf + 1.0, cf/pf) - 1.0
    else
	return power(e_, ina/pf) - 1.0		  -- continous interest
    end if
end function --ipp

global function fin
	(atom n, atom i, atom pv, atom pmt, atom fv, atom k, integer w)

		     -- formulae:  pv(1+i)^n+pmt(1/i+k)[(1+i)^n-1]+fv=0

			    -- n   = number of periods		    (1)
			    -- i   = interest rate per period	    (2)
			    -- pv  = present value		    (3)
			    -- pmt = payment per period 	    (4)
			    -- fv  = final value		    (5)
			    -- k   = 0/1 for ordinary/due annuities (6)

		  -- w is in 1..6 depending on the value to be obtained

-- For w=2, the interest is calculated (by an iterative process) to the
-- maximum number of digits let by the hardare/software.  If the 2nd
-- parameter given in the call is 0, the program looks for a very good
-- starting point; if isn't 0, the value passed is used as (so desired
-- by the user) the starting point.
-- In all the other cases, w=1,3,4,5 or even 6 (intermediate point) the
-- corresponding value passed is not honoured.

    atom v, i0, dxjm1, dx, x, xjp1

    if w < 1 or 6 < w then
	puts(ERR, "w must be an integer in 1..6\n")
	abort (1)

    elsif w = 1 then				-- {n	CASE}
	return log((pmt*(1/i + k) - fv)/(pv + pmt*(1/i + k)))/log(1+i)

    elsif w = 2 then				-- {i	CASE}
	if pmt = 0 then
	    return power(-fv/pv, 1/n) - 1.0
	elsif i = 0 then
	    v = (abs(pv) + abs(fv)) / abs(pmt)
	    i0 = 1.0/v + v/(n*n*n)	    -- very good starting guess
	else	  -- only in this case the passed parameter is honoured
	    i0 = i
	end if
	dxjm1 = 3.4E38	x = i0			      -- (for instance)
	while TRUE do
	    dx = -(pv*power(1+x,n)+pmt*(1/x+k)*(power(1+x,n)-1)+fv) /
		 (pv*n*power(1+x,n-1) + pmt*(-1/(x*x)*(power(1+x,n)-1)
					   +(1/x+k)*n*power(1+x,n-1)))
	    xjp1 = x + dx
	    if xjp1 = x or dx/dxjm1 <= -1 then
		exit
	    end if
	    dxjm1 = dx	x = xjp1		  -- values are updated
	end while
	return x

    elsif w = 3 then				-- {pv	CASE}
	return (pmt*(1/i + k)*(1 - power(1+i, n)) - fv)/power(1+i, n)

    elsif w = 4 then				-- {pmt CASE}
	if fv = -pv then
	    return fv/(1/i + k) 			-- perpetuity
	else
	    return (-pv*power(1+i,n) - fv)/((1/i+k)*(power(1+i,n) - 1))
	end if

    elsif w = 5 then				-- {fv	CASE}
	return pmt*(1/i + k)*(1 - power(1+i, n)) - pv*power(1+i, n)

    else					-- {w	CASE}
	return (pv*power(1+i,n) + fv)/(pmt*(1 - power(1+i,n))) - 1/i

    end if
end function --fin

