
-----------------------------------------------------------------------
-- Test of the Financial Calculator			    October '06
-----------------------------------------------------------------------
-- Author:  Jaime Marcos			    <jmarcos2@xtec.net>

with profile -- _time 25000
with trace   --  trace(1)

include FinCal.e

constant g="\t%0.16g\n"
constant ANY = NaN_	-- (... to be sure) Or whatever you like!
atom	 tmp

-- It follows a battery of financial examples.
-- Credits:  PPC ROM User's Manual, pp. 150-152


-- SIMPLE INTEREST.  Find the annual simple interest rate for an $800
-- loan to be repayed at the end of one year with a single payment of
-- $896.

printf(1,"i   ="&g, fin(1, ANY, -800, 0, 896, -6, 2))
			-- k doesn't matter; put arbitrarily to -6
					-- i   =  0.1200000000000001

-- COMPOUND INTEREST.  Find the future value of $800 after one year at
-- a nominal rate of 12% compounded monthly.

printf(1,"fv  ="&g, fin(1*12, .12/12, -800, 0, ANY, -6, 5))
			-- k doesn't matter; put arbitrarily to -6
					-- fv  =  901.4600241055758

-- PERIODIC PAYMENT.  Find the monthly end-of-period payment required
-- to fully amortize the loan in the previous example.

printf(1,"pmt ="&g, fin(12, .12/12, -800, ANY, 0, 0, 4))
					-- pmt =  71.07903094267334

-- CONVENTIONAL MORTGAGE.  Find the number of monthly payments
-- required to fully amortize a loan of $100000 at a nominal annual
-- rate of 13.25% compounded monthly, if end-of-period payments of
-- $1125.75 are made.

printf(1,"n   ="&g, fin(ANY, .1325/12, .1E6, -1125.75, 0, 0, 1))
					-- n   =  360.0972979789752

-- FINAL PAYMENT.  For the preceding example, find the amount of the
-- supplementary final payment if n is changed to 360.

printf(1,"fv  ="&g, fin(360, .1325/12, .1E6, -1125.75, ANY, 0, 5))
					-- fv  = -108.8747264919802

-- BALLOON PAYMENT.  If the monthly payment in the provious example is
-- rounded down to $1125.00, how much balloon payment will be due with
-- the final regular payment?

printf(1,"fv  ="&g, fin(360, .1325/12, .1E6, -1125, ANY, 0, 5))
					-- fv  = -3579.994909740984

-- CANADIAN MORTGAGE.  Find the monthly end-of-period payment required
-- to fully amortize a 25 year $85000 loan at 11% compounded
-- semiannually.

printf(1,"pmt ="&g, fin(25*12, ipp(.11, 2, 12), 85E3, ANY, 0, 0, 4))
					-- pmt = -818.1497941159764

-- EUROPEAN MORTGAGE.  For a 30 year $90000 mortgage at an "effective
-- annual rate" of 14%, compute the monthly end-of period payments.
-- Set the compounding frequency to 1.

printf(1,"pmt ="&g, fin(30*12, ipp(.14, 1, 12), 90E3, ANY, 0, 0, 4))
					-- pmt = -1007.878327937546

-- BI-WEEKLY SAVINGS.  Compute the future value of bi-weekly savings of
-- $100 for 3 years at a nominal annual rate of 5.5% compounded daily.

printf(1,"fv  ="&g, fin(3*26, ipp(.055, 365, 26), 0, -100, ANY, 1, 5))
					-- fv  =  8489.319904917091

-- PRESENT VALUE - ANNUITY DUE.  What is the present value of $500 to
-- be received at the beginning of each quarter over a 10 year period
-- if money is being discounted at a nominal annual rate of 10%,
-- compounded monthly?

printf(1,"pv  ="&g, fin(10*4, ipp(.10, 12, 4), ANY, 500, 0, 1, 3))
					-- pv  = -12822.63969398361

-- BALLOON PAYMENT AT n+1.  Compute the monthly end-of-period payment
-- on a 3 year $20000 loan at a nominal annual rate of 15% compounded
-- monthly, with a $10000 balloon payment due at the end of the 37th
-- period. The balloon payment must be discounted one period to make it
-- copicide with the last regular payment.

printf(1,"pmt ="&g, fin(3*12, .15/12, 2E4, ANY, -1E4/(1+.15/12), 0, 4))
					-- pmt = -474.3897453511015

-- EQUIVALENT PAYMENTS.  Find the equivalent monthly payment required
-- to amortize a 20 year $40000 loan at a nominal annual rate of 10.5%
-- compounded monthly, with 10 annual payments of $5029.71 remaining.
-- Compute PV of the remaining annual payments, then change n and PF to
-- a monthly basis and compute the equivalent monthly PMT.

	  tmp =     fin(10, ipp(.105, 12, 1), ANY, -5029.71, 0, 0, 3)
printf(1,"pv  ="&g, tmp)
					-- pv  =  29595.87627422594
printf(1,"pmt ="&g, fin(10*12, .105/12, 40E3, ANY, -tmp, 0, 4))
					-- pmt = -399.3519575384477

-- PERPETUITY - CONTINOUS COMPOUNDING.	If you can purchase a single
-- payment annuity with an initial investment of $60000 that will be
-- invested at a nominal annual rate of 15% compounded continously,
-- what is the the maximum monthly return you can receive without
-- reducing the $60000 principal?

printf(1,"pmt ="&g, fin(-1, ipp(.15, inf_, 12), -6E4, ANY, 6E4, 0, 4))
			-- n doesn't matter; put arbitrarily to -1
					-- pmt =  754.7070924380649

